Page 85 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 85

Home

    Building Modern Babylon

    Alas, alas, that great city, that was clothed in fine
    linen, and purple, and scarlet, and decked with gold, and
    precious stones, and pearls!

    n tat 1947

    ... for thy merchants were the great men of the earth;
    for by thy sorceries were all nations deceived.

    n tat 1a.Nn

    At the beginning of the 20th century, in New York,
    there began an association known as the "Money Trust.”
    This came about because of a combining of European
    and United States banking interests, and was centered

    around powerful American money barons such as J. P.
    Morgan, John D. Rockefeller, and Bernard Baruch. One
    of America's most powerful banking firms, Kuhn, Loeb
    and Company, with ties to the Rothschilds’ European
    banking dynasty, was also involved.

    In 1902, Paul Warburg (a German banker associated

    with the Rothschilds) came to the United States and was
    paid a $500,000 yearly salary while campaigning for the
    establishment of a central banking system. This system
    was patterned after the European system where the

    80

    Chapter 10

    Revelation 18:16

    Revelation 18:23